==> simgrid_3.9~rc1.orig.tar.gz: SimGrid-3.9/doc/html/advanced.js <==
var advanced =
[
    [ "Bindings", "bindings.html", [
      [ "Java Binding", "bindings.html#bindings_binding_Java", null ],
      [ "Ruby Binding", "bindings.html#bindings_binding_Ruby", null ],
      [ "Lua Binding", "bindings.html#bindings_binding_lua", [
        [ "What is lua ?", "bindings.html#bindings_binding_lua_about", [
          [ "Why lua ?", "bindings.html#bindings_binding_lua_why", null ],
          [ "How to use lua in Simgrid ?", "bindings.html#bindings_binding_lua_simgrid", null ]
        ] ],
        [ "Master/Slave Example", "bindings.html#bindings_binding_lua_example_master_slave", null ],
        [ "Exchanging Data", "bindings.html#bindings_binding_lua_example_data", null ],
        [ "Bypass XML", "bindings.html#bindings_binding_lua_example_bypass", null ],
        [ "Master/slave Lua application", "bindings.html#MSG_ex_master_slave_lua", [
          [ "Master code", "bindings.html#MSG_ext_ms_master_lua", null ],
          [ "Slave code", "bindings.html#MSG_ext_ms_slave_lua", null ],
          [ "Simulation core", "bindings.html#MSG_ext_ms_core_lua", null ]
        ] ],
        [ "Master/slave Bypass Lua application", "bindings.html#MSG_ex_master_slave_lua_bypass", [
          [ "Master code", "bindings.html#MSG_ext_ms_bp_master_lua", null ],
          [ "Slave code", "bindings.html#MSG_ext_ms_bp_slave_lua", null ],
          [ "Simulation core", "bindings.html#MSG_ext_ms_bp_core_lua", null ]
        ] ]
      ] ]
    ] ],
    [ "Packet level simulation", "pls.html", [
      [ "Using GTNetS", "pls.html#pls_simgrid_configuration_gtnets", null ],
      [ "Using NS3", "pls.html#pls_simgrid_configuration_ns3", null ]
    ] ],
    [ "SimGrid internals", "internals.html", "internals" ],
    [ "Contributing to SimGrid", "contributing.html", [
      [ "Spread the word", "contributing.html#contributing_spread", null ],
      [ "Reporting (and fixing) any issue you find", "contributing.html#contributing_bugs", null ],
      [ "Contributing features and associated tools", "contributing.html#contributing_contrib", null ]
    ] ]
];

==> simgrid_3.10.orig.tar.gz: SimGrid-3.10/doc/html/advanced.js <==
var advanced =
[
    [ "Bindings", "bindings.html", [
      [ "Ruby Binding", "bindings.html#MSG_Ruby", null ],
      [ "Java Binding", "bindings.html#MSG_Java", [
        [ "Who should use this (and who shouldn't)", "bindings.html#bindings_binding_Java_jMSG_who", null ],
        [ "Usage overview", "bindings.html#SimGrid-java", null ],
        [ "How to install Simgrid-java", "bindings.html#bindings_binding_java_install", [
          [ "How to use Simgrid-java", "bindings.html#bindings_binding_java_use", null ],
          [ "How to use the coroutines context factory", "bindings.html#bindings_binding_java_coroutines", null ],
          [ "Getting a mlvm JVM", "bindings.html#bindings_java_coro_install", null ],
          [ "Using coroutine contexts", "bindings.html#bindings_java_coro_use", null ]
        ] ]
      ] ],
      [ "Lua Binding", "bindings.html#bindings_binding_lua", [
        [ "What is lua ?", "bindings.html#bindings_binding_lua_about", [
          [ "Why lua ?", "bindings.html#bindings_binding_lua_why", null ],
          [ "How to use lua in Simgrid ?", "bindings.html#bindings_binding_lua_simgrid", null ]
        ] ],
        [ "Master/Slave Example", "bindings.html#bindings_binding_lua_example_master_slave", null ],
        [ "Exchanging Data", "bindings.html#bindings_binding_lua_example_data", null ],
        [ "Bypass XML", "bindings.html#bindings_binding_lua_example_bypass", null ],
        [ "Master/slave Lua application", "bindings.html#MSG_ex_master_slave_lua", [
          [ "Master code", "bindings.html#MSG_ext_ms_master_lua", null ],
          [ "Slave code", "bindings.html#MSG_ext_ms_slave_lua", null ],
          [ "Simulation core", "bindings.html#MSG_ext_ms_core_lua", null ]
        ] ],
        [ "Master/slave Bypass Lua application", "bindings.html#MSG_ex_master_slave_lua_bypass", [
          [ "Master code", "bindings.html#MSG_ext_ms_bp_master_lua", null ],
          [ "Slave code", "bindings.html#MSG_ext_ms_bp_slave_lua", null ],
          [ "Simulation core", "bindings.html#MSG_ext_ms_bp_core_lua", null ]
        ] ]
      ] ]
    ] ],
    [ "Packet level simulation", "pls.html", [
      [ "Using GTNetS", "pls.html#pls_simgrid_configuration_gtnets", null ],
      [ "Using NS3", "pls.html#pls_simgrid_configuration_ns3", null ]
    ] ],
    [ "SimGrid internals", "internals.html", "internals" ],
    [ "Contributing to SimGrid", "contributing.html", [
      [ "Spread the word", "contributing.html#contributing_spread", null ],
      [ "Reporting (and fixing) any issue you find", "contributing.html#contributing_bugs", null ],
      [ "Contributing features and associated tools", "contributing.html#contributing_contrib", null ]
    ] ]
];
